Package: mFD
Title: Compute and Illustrate the Multiple Facets of Functional
        Diversity
Version: 1.0.7
Authors@R: c(
    person(given   = "Camille",
           family  = "Magneville",
           email   = "camille.magneville@gmail.com",
           role    = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-0489-3822")),
    person(given   = "Nicolas",
           family  = "Loiseau",
           email   = "nicolas.loiseau1@gmail.com",
           role    = "aut",
           comment = c(ORCID = "0000-0002-2469-1980")),
    person(given   = "Camille",
           family  = "Albouy",
           email   = "albouycamille@gmail.com",
           role    = "aut",
           comment = c(ORCID = "0000-0003-1629-2389")),
    person(given   = "Nicolas",
           family  = "Casajus",
           email   = "nicolas.casajus@fondationbiodiversite.fr",
           role    = "aut",
           comment = c(ORCID = "0000-0002-5537-5294")),
    person(given   = "Thomas",
           family  = "Claverie",
           email   = "tclaverie@gmail.com",
           role    = "aut",
           comment = c(ORCID = "0000-0002-6258-4991")),
    person(given   = "Arthur",
           family  = "Escalas",
           email   = "arthur.escalas@gmail.com",
           role    = "aut",
           comment = c(ORCID = "0000-0002-6450-5716")),
    person(given   = "Fabien",
           family  = "Leprieur",
           email   = "fabien.leprieur@umontpellier.fr",
           role    = "aut",
           comment = c(ORCID = "0000-0001-6869-342X")),
    person(given   = "Eva",
           family  = "Maire",
           email   = "emg.maire@gmail.com",
           role    = "aut",
           comment = c(ORCID = "0000-0002-1032-3394")),
    person(given   = "David",
           family  = "Mouillot",
           email   = "david.mouillot@umontpellier.fr",
           role    = "aut",
           comment = c(ORCID = "0000-0003-0402-2605")),
    person(given   = "Sebastien",
           family  = "Villeger",
           email   = "sebastien.villeger@cnrs.fr",
           role    = "aut",
           comment = c(ORCID = "0000-0002-2362-7178")))
Description: Computing functional traits-based distances between pairs of 
    species for species gathered in assemblages allowing to build several
    functional spaces. The package allows to compute functional diversity
    indices assessing the distribution of species (and of their dominance) in a
    given functional space for each assemblage and the overlap between
    assemblages in a given functional space, see: Chao et al. (2018)
    <doi:10.1002/ecm.1343>, Maire et al. (2015) <doi:10.1111/geb.12299>,
    Mouillot et al. (2013) <doi:10.1016/j.tree.2012.10.004>, Mouillot et al.
    (2014) <doi:10.1073/pnas.1317625111>, Ricotta and Szeidl (2009)
    <doi:10.1016/j.tpb.2009.10.001>. Graphical outputs are included.
    Visit the 'mFD' website for more information, documentation and examples.
URL: https://cmlmagneville.github.io/mFD/,
        https://github.com/CmlMagneville/mFD
BugReports: https://github.com/CmlMagneville/mFD/issues
License: GPL-2
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5)
Imports: ade4, ape, betapart (>= 1.5.4), cluster, dendextend,
        FactoMineR, gawdis, geometry, ggplot2, ggrepel, grid, Hmisc,
        patchwork, reshape2, rstatix, stats, utils, vegan
Suggests: dplyr (>= 1.0.6), knitr, magrittr, rmarkdown (>= 2.6),
        stringr, tibble, tidyr
RoxygenNote: 7.2.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-02-26 10:43:42 UTC; au749321
Author: Camille Magneville [aut, cre, cph]
    (<https://orcid.org/0000-0003-0489-3822>),
  Nicolas Loiseau [aut] (<https://orcid.org/0000-0002-2469-1980>),
  Camille Albouy [aut] (<https://orcid.org/0000-0003-1629-2389>),
  Nicolas Casajus [aut] (<https://orcid.org/0000-0002-5537-5294>),
  Thomas Claverie [aut] (<https://orcid.org/0000-0002-6258-4991>),
  Arthur Escalas [aut] (<https://orcid.org/0000-0002-6450-5716>),
  Fabien Leprieur [aut] (<https://orcid.org/0000-0001-6869-342X>),
  Eva Maire [aut] (<https://orcid.org/0000-0002-1032-3394>),
  David Mouillot [aut] (<https://orcid.org/0000-0003-0402-2605>),
  Sebastien Villeger [aut] (<https://orcid.org/0000-0002-2362-7178>)
Maintainer: Camille Magneville <camille.magneville@gmail.com>
Repository: CRAN
Date/Publication: 2024-02-26 14:00:06 UTC
Built: R 4.2.3; ; 2024-02-26 15:57:34 UTC; unix
