# Generated by roxygen2: do not edit by hand

export(alpha.fd.fe)
export(alpha.fd.fe.plot)
export(alpha.fd.hill)
export(alpha.fd.multidim)
export(alpha.multidim.plot)
export(asb.sp.summary)
export(background.plot)
export(beta.fd.hill)
export(beta.fd.multidim)
export(beta.multidim.plot)
export(dist.nearneighb)
export(dist.point)
export(dist.to.df)
export(fdis.plot)
export(fdiv.plot)
export(feve.plot)
export(fide.plot)
export(fnnd.plot)
export(fori.plot)
export(fric.plot)
export(fspe.plot)
export(funct.dist)
export(funct.space.plot)
export(fuse)
export(mst.computation)
export(panels.to.patchwork)
export(pool.plot)
export(quality.fspaces)
export(quality.fspaces.plot)
export(sp.filter)
export(sp.to.fe)
export(sp.tr.summary)
export(tr.cont.fspace)
export(tr.cont.scale)
export(traits.faxes.cor)
export(vertices)
import(patchwork)
importFrom(stats,summary.lm)
